#!/bin/bash

# loop through AOR files given on command line without extension
# e.g.: $ ./duration_cal.sh HIFI_AOR_C010_32
for AOR in $*
do
  echo "next AOR file = $AOR"

  # create an empty summary file
  rm -f summary_$AOR.log
  touch summary_$AOR.log

  # the full name of the AOR file
  aorfile=$AOR.aor
  # pick up all engineering modes
  modes=$(grep aotName $aorfile | sort -u | sed -e 's/^.*<v07:aotName>\(.*\)Gen<\/v07:aotName>.*$/\1/')
  
  # for each of the modes run 'cus -defdur' and append to summary file
  for m in $modes
  do
    echo "-- mode $m"
    cus -defdurtotal $m -properties hcss.cus.outputfile=/tmp/cus.log > /dev/null 2>&1
    cat /tmp/cus.log >> summary_$AOR.log
  done

  # check if HifiPoint AOTs are used
  grep -q HifiPoint $aorfile
  if [ $? -eq 0 ]
  then
    # for each point mode run 'cus -defdur' and append to summary file
    for m in HifiPointModeDBS \
             HifiPointModeFastDBS \
             HifiPointModeFSwitch \
             HifiPointModeFSwitchNoRef \
             HifiPointModeLoadChop \
             HifiPointModeLoadChopNoRef \
             HifiPointModePositionSwitch
    do
        echo "-- mode $m"
        cus -defdurtotal $m -properties hcss.cus.outputfile=/tmp/cus.log > /dev/null 2>&1
        cat /tmp/cus.log >> summary_$AOR.log
    done
  fi

  # check if HifiMapping AOTs are used
  grep -q HifiMapping $aorfile
  if [ $? -eq 0 ]
  then
    # for each mapping mode run 'cus -defdur' and append to summary file
    for m in HifiMappingModeDBSCross \
             HifiMappingModeDBSRaster \
             HifiMappingModeFastDBSCross \
             HifiMappingModeFastDBSRaster \
             HifiMappingModeFSwitchOTF \
             HifiMappingModeFSwitchOTFNoRef \
             HifiMappingModeLoadChopOTF \
             HifiMappingModeLoadChopOTFNoRef \
             HifiMappingModeOTF
    do
        echo "-- mode $m"
        cus -defdurtotal $m -properties hcss.cus.outputfile=/tmp/cus.log > /dev/null 2>&1
        cat /tmp/cus.log >> summary_$AOR.log
    done
  fi

  # check if HifiFS AOTs are used
  grep -q HifiFS $aorfile
  if [ $? -eq 0 ]
  then
    # for each sscan mode run 'cus -defdur' and append to summary file
    for m in HifiSScanModeDBS \
           HifiSScanModeFastDBS \
           HifiSScanModeFSwitch \
           HifiSScanModeFSwitchNoRef \
           HifiSScanModeLoadChop \
           HifiSScanModeLoadChopNoRef
    do
        echo "-- mode $m"
        cus -defdurtotal $m -properties hcss.cus.outputfile=/tmp/cus.log > /dev/null 2>&1
        cat /tmp/cus.log >> summary_$AOR.log
    done
  fi
  # cus doesn't put EOLs, so add an extra empty line 
  echo "" >> summary_$AOR.log
  cat summary_$AOR.log
done
